<?php
/**
 * StagFramework functions and definitions.
 *
 * @package StagFramework
 */
if ( ! isset( $content_width ) ) {
	$content_width = 970;
}

/*
 * Set Retina Cookie
 */
global $is_retina;
( isset( $_COOKIE['retina'] ) ) ? $is_retina = true : $is_retina = false;

if ( ! function_exists( 'stag_theme_setup' ) ) :

	function stag_theme_setup() {

		/* Load translation domain ---------------------------------------------*/
		load_theme_textdomain( 'doctype', get_template_directory() . '/languages' );

		$locale = get_locale();

		$locale_file = get_template_directory() . "/languages/$locale.php";
		if ( is_readable( $locale_file ) ) {
			require_once $locale_file;
		}

		/* Register Menus ------------------------------------------------------*/
		register_nav_menus(
			array(
				'primary' => __( 'Primary Menu', 'doctype' ),
			)
		);

		/**
		 * Enable support for Post Thumbnails on posts and pages
		 *
		 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		 */
		add_theme_support( 'post-thumbnails' );

		/**
		 * Add support for title tag.
		 *
		 * @since 2.0.0.
		 */
		add_theme_support( 'title-tag' );

		/**
		 * Add theme support for Selective widget refresh.
		 *
		 * @since 2.0.0.
		 */
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Switches default core markup for search form, comment form, and comments
		// to output valid HTML5.
		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );

		/**
		* StagFramework specific theme support
		*
		* @uses Stagtools
		* @link http://wordpress.org/plugins/stagtools/
		*/
		add_theme_support( 'stag-portfolio' );

		/**
		* Add default posts and comments RSS feed links to head
		*/
		add_theme_support( 'automatic-feed-links' );

		set_post_thumbnail_size( 1170, 396, true );
		add_image_size( 'portfolio-thumbnail', 370, 370, true );

		/**
		 * Add Gutenberg Support.
		 *
		 * @since 2.0.0.
		 */
		add_theme_support( 'align-wide' );
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'responsive-embeds' );
		add_theme_support( 'editor-styles' );

		// This theme styles the visual editor with editor-style.css to match the theme style.
		add_editor_style( '/assets/css/editor-style.css' );

		// Theme Upgrade Functions.
		doctype_theme_upgrade();
	}
endif;
add_action( 'after_setup_theme', 'stag_theme_setup' );

if ( ! function_exists( 'stag_sidebar_init' ) ) :
	/**
	 * Register widget areas
	 *
	 * @return void
	 */
	function stag_sidebar_init() {
		register_sidebar(
			array(
				'name'          => __( 'Footer Widgets', 'doctype' ),
				'id'            => 'sidebar-footer',
				'before_widget' => '<aside id="%1$s" class="widget grid-4 %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h3 class="widget-title"><span>',
				'after_title'   => '</span></h3>',
				'description'   => __( 'Footer Widgets Area.', 'doctype' ),
			)
		);

		register_sidebar(
			array(
				'name'          => __( 'Homepage Sections', 'doctype' ),
				'id'            => 'sidebar-homepage',
				'before_widget' => '<section id="%1$s" class="section-homepage %2$s"><div class="inside">',
				'after_widget'  => '</div></section>',
				'before_title'  => '<h2 class="section-title">',
				'after_title'   => '</h2>',
				'description'   => __( 'Here you can configure the layout of the Homepage.', 'doctype' ),
			)
		);
	}
endif;
add_action( 'widgets_init', 'stag_sidebar_init' );

/**
 * Enqueue editor styles for Gutenberg
 */
function doctype_block_editor_styles() {

	// Enqueue Google Fonts.
	wp_enqueue_style( 'doctype-fonts', doctype_get_google_font_uri(), array(), STAG_THEME_VERSION );

	$font_body        = doctype_get_thememod_value( 'font-body' );
	$font_header      = doctype_get_thememod_value( 'font-headers' );
	$accent_color     = doctype_get_thememod_value( 'accent-color' );
	$background_color = doctype_get_thememod_value( 'style_background_color' );

	wp_add_inline_style(
		'doctype-fonts', "
		.editor-styles-wrapper {
			--accent-color: {$accent_color};
			--style-background-color: {$background_color};
			--font-body: '{$font_body}';
			--font-header: '{$font_header}';
		}"
	);

}
add_action( 'enqueue_block_editor_assets', 'doctype_block_editor_styles' );

/**
 * Enqueues scripts and styles for front end.
 *
 * @return void
 */
function stag_scripts_styles() {
	if ( ! is_admin() ) :
		global $is_IE;

		/* Register Scripts ---------------------------------------------------*/
		wp_register_script( 'stag-custom', get_template_directory_uri() . '/assets/js/jquery.custom.js', array( 'jquery' ), STAG_THEME_VERSION, true );
		wp_register_script( 'stag-plugins', get_template_directory_uri() . '/assets/js/plugins.js', array( 'jquery' ), STAG_THEME_VERSION, true );
		wp_register_script( 'responsiveSlides', get_template_directory_uri() . '/assets/js/jquery.responsiveSlides.js', array( 'jquery' ), '1.55', true );
		wp_register_script( 'mixitup', get_template_directory_uri() . '/assets/js/jquery.mixitup.min.js', array( 'jquery' ), '1.5.4', true );
		wp_register_script( 'html5shiv', get_template_directory_uri() . '/assets/js/html5shiv.js', array(), '3.7.3', false );
		wp_register_script( 'css3-mediaqueries', get_template_directory_uri() . '/assets/js/css3-mediaqueries.min.js', array(), '1.0.0', false );

		/* Enqueue Scripts ---------------------------------------------------*/
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'stag-custom' );
		wp_enqueue_script( 'stag-plugins' );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' ); // loads the javascript required for threaded comments.
		}

		if ( is_single() && 'portfolio' === get_post_type() ) {
			wp_enqueue_script( 'responsiveSlides' );
		}

		if ( is_page_template( 'template-portfolio-filterable.php' ) ) {
			wp_enqueue_script( 'mixitup' );
		}

		wp_localize_script(
			'stag-custom', 'stag', array(
				'ajaxurl'   => admin_url( 'admin-ajax.php' ),
				'menuState' => doctype_get_thememod_value( 'doctype_fixed_navigation' ),
			)
		);

		/* Enqueue Styles ---------------------------------------------------*/
		wp_enqueue_style( 'stag-style', get_stylesheet_uri(), '', STAG_THEME_VERSION );
		wp_enqueue_style( 'doctype-fonts', doctype_get_google_font_uri(), array(), null );

		$output = apply_filters( 'stag_custom_styles', '' );
		wp_add_inline_style( 'stag-style', $output );

		if ( $is_IE ) {
			wp_enqueue_script( 'html5shiv' );
			wp_enqueue_script( 'css3-mediaqueries' );
		}

	endif;
}
add_action( 'wp_enqueue_scripts', 'stag_scripts_styles' );


/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function cluster_required_plugins() {
	$plugins = array(

		// This is an example of how to include a plugin from the WordPress Plugin Repository.
		array(
			'name'     => __( 'StagTools', 'doctype' ),
			'slug'     => 'stagtools',
			'required' => true,
		),
		array(
			'name'             => __( 'Doctype Assistant', 'doctype' ),
			'slug'             => 'doctype-assistant',
			'source'           => get_parent_theme_file_path() . '/assistant/doctype-assistant.zip',
			'required'         => true,
			'force_activation' => true,
			'version'          => '1.0',
			'external_url'     => 'https://github.com/codestag/doctype-assistant/',
		),
		array(
			'name'         => __( 'Envato Market', 'doctype' ),
			'slug'         => 'wp-envato-market',
			'source'       => 'https://envato.github.io/wp-envato-market/dist/envato-market.zip',
			'required'     => false,
			'version'      => '1.0.0',
			'external_url' => 'http://envato.github.io/wp-envato-market/',
		),

	);

	tgmpa( $plugins );
}
add_action( 'tgmpa_register', 'cluster_required_plugins' );

/**
 * Replaces the excerpt "more" text by a link
 */
function new_excerpt_more( $more ) {
	global $post;
	return ' <a class="moretag" href="' . get_permalink( $post->ID ) . '">' . __( 'Read More&hellip;', 'doctype' ) . '</a>';
}
add_filter( 'excerpt_more', 'new_excerpt_more' );

/**
 * Add post classes to portfolio items for filtering portfolio
 *
 * @since 1.0.1
 * @return array New post class array
 */
function doctype_portfolio_mixitup_class( $classes ) {
	$skills = get_the_terms( get_the_ID(), 'skill' );

	$skill = array();
	if ( $skills ) {
		if ( is_array( $skills ) ) {
			foreach ( $skills as $ski ) {
				$skill[] = $ski->slug;
			}
			$classes[] = implode( $skill, ' ' );
		}
	}
	$classes[] = 'mix';

	return $classes;
}
add_filter( 'post_class', 'doctype_portfolio_mixitup_class' );


/**
 * Add body class for sticky navigation
 *
 * @since 1.0.2
 * @return array New body class array
 */
function sticky_nav_body_class( $classes ) {
	$nav = doctype_get_thememod_value( 'doctype_fixed_navigation' );

	if ( isset( $nav ) && $nav == 'on' ) {
		$classes[] = 'sticky-nav';
	}

	return $classes;
}
add_filter( 'body_class', 'sticky_nav_body_class' );

function doctype_stag_custom_sidebar_widget_args() {
	return array(
		'before_widget' => '<section id="%1$s" class="section-homepage %2$s"><div class="inside">',
		'after_widget'  => '</div></section>',
		'before_title'  => '<h2 class="section-title">',
		'after_title'   => '</h2>',
	);
}
add_filter( 'stag_custom_sidebars_widget_args', 'doctype_stag_custom_sidebar_widget_args' );


if ( ! function_exists( 'doctype_assistant_notice' ) ) {
	/**
	 * Alerts if assistant plugin is not activated.
	 *
	 * @since 2.1.0
	 * @return void
	 */
	function doctype_assistant_notice() {
		if ( ! class_exists( 'Doctype_Assistant' ) && current_user_can( 'activate_plugins' ) ) {
			$page_link = self_admin_url( 'themes.php?page=tgmpa-install-plugins' );
			$message       = '<p>' . sprintf( '%1$s<br><strong>%2$s<a href="%3$s">this page</a>.', __('As per ThemeForest guidelines, some functionalities are now excluded from theme and moved to an assistant plugin.', 'doctype' ), __( 'To use Doctype with full features, please activate Doctype Assistant from ', 'doctype' ), esc_url( $page_link ) ) . '</strong></p>';

			echo '<div class="error">' . $message . '</div>'; // phpcs:ignore
		}
	}

}
add_action( 'admin_notices', 'doctype_assistant_notice' );


require_once get_template_directory() . '/framework/stag-framework.php';

/**
 * Customizer Support & Functions for this theme.
 */
require_once get_template_directory() . '/inc/customizer/load.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';
require_once get_template_directory() . '/inc/upgrade.php';

require_once get_template_directory() . '/inc/updater/theme-updater.php';
