<?php
/**
 * Customizer settings definitions.
 *
 * @package DOCTYPE
 * @since 2.0.0.
 */

/**
 * Get the array of definitions for Customizer settings and controls.
 *
 * @since 2.0.0.
 *
 * @param  object $wp_customize    The Customizer instance.
 *
 * @return mixed|void
 */
function doctype_customize_get_definitions( $wp_customize ) {
	$google_fonts = doctype_all_font_choices();

	$wp_customize->add_panel(
		'doctype_options_panel', array(
			'title'       => esc_html__( 'Theme Options', 'doctype' ),
			'description' => esc_html__( 'Configure your theme settings', 'doctype' ),
			'priority'    => 999,
		)
	);

	$definitions = array(
		'colors'            => array(
			'title'       => esc_html__( 'Styling Options', 'doctype' ),
			'description' => 'Configure your theme style & accents',
			'priority'    => '',
			'options'     => array(
				'style_background_color' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Background Color', 'doctype' ),
					),
				),
				'accent-color'           => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Accent Color', 'doctype' ),
					),
				),
			),
		),
		'general_settings'  => array(
			'title'   => esc_html__( 'General Settings', 'doctype' ),
			'panel'   => 'doctype_options_panel',
			'options' => array(
				'doctype_text_logo'        => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'checkbox',
						'label'       => esc_html__( 'Plain Text Logo', 'doctype' ),
						'description' => esc_html( 'Check this box to enable a plain text logo rather than an image logo. Will use your site title.', 'doctype' ),
					),
				),
				'doctype_custom_logo'      => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'         => esc_html__( 'Custom Logo Upload', 'doctype' ),
						'description'   => esc_html__( 'Upload a logo for your theme.', 'doctype' ),
						'control_class' => 'WP_CUSTOMIZE_IMAGE_CONTROL',
					),
				),
				'doctype_contact_email'    => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Contact Form Email Address', 'doctype' ),
						'description' => esc_html__( 'Enter the email address where you\'d like to receive emails from the contact form, or leave blank to use admin email.', 'doctype' ),
						'type'        => 'text',
					),
				),
				'doctype_tracking_code'    => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Tracking Code', 'doctype' ),
						'description' => esc_html__( 'Paste your Google Analytics (or other) tracking code here. It will be inserted before the closing body tag of your theme.', 'doctype' ),
						'type'        => 'textarea',
					),
				),
				'doctype_site_footer_left'      => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Footer Text Left', 'doctype' ),
						'description' => esc_html__( 'Enter the site left footer text.', 'doctype' ),
						'type'        => 'textarea',
					),
				),

				'doctype_site_footer_right'      => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Footer Text Right', 'doctype' ),
						'description' => esc_html__( 'Enter the site right footer text.', 'doctype' ),
						'type'        => 'textarea',
					),
				),
				'doctype_theme_credit'     => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => esc_html__( 'Hide Theme Credit', 'doctype' ),
						'type'  => 'checkbox',
					),
				),
				'doctype_fixed_navigation' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => esc_html__( 'Enable Sticky Navigation', 'doctype' ),
						'type'  => 'checkbox',
					),
				),
			),
		),
		'blog_settings'     => array(
			'title'   => esc_html__( 'Blog Settings', 'doctype' ),
			'panel'   => 'doctype_options_panel',
			'options' => array(
				'doctype_blog_title'    => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Blog Title', 'doctype' ),
						'description' => esc_html__( 'Choose the title for blog page', 'doctype' ),
					),
				),
				'doctype_blog_subtitle' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Blog Subtitle', 'doctype' ),
						'description' => esc_html__( 'Choose the subtitle for blog page', 'doctype' ),
					),
				),
			),
		),
		'doctype_fonts'     => array(
			'title'       => esc_html__( 'Fonts', 'doctype' ),
			'panel'       => 'doctype_options_panel',
			'description' => sprintf(
				/* translators: Link to Google Fonts website */
				esc_html__( 'The list of Google fonts is long! You can %s before making your choices.', 'doctype' ),
				sprintf(
					'<a href="%1$s" class="external-link" target="_blank">%2$s</a>',
					esc_url( 'https://fonts.google.com' ),
					esc_html__( 'preview', 'doctype' )
				)
			),
			'options'     => array(
				'font-body'          => array(
					'setting' => array(),
					'control' => array(
						'type'    => 'select',
						'choices' => $google_fonts,
						'label'   => esc_html__( 'Body', 'doctype' ),
					),
				),
				'font-headers'       => array(
					'setting' => array(),
					'control' => array(
						'type'    => 'select',
						'choices' => $google_fonts,
						'label'   => esc_html__( 'Headers', 'doctype' ),
					),
				),
				'google-font-subset' => array(
					'setting' => array(),
					'control' => array(
						'type'        => 'select',
						'choices'     => doctype_get_google_font_subsets(),
						'label'       => esc_html__( 'Google Font Subset', 'doctype' ),
						'description' => sprintf(
							/* translators: Link to Google fonts website */
							esc_html__( 'Not all fonts provide each of these subsets. Please visit the %s to see which subsets are available for each font.', 'doctype' ),
							sprintf(
								'<a href="%1$s" target="_blank">%2$s</a>',
								esc_url( 'https://fonts.google.com' ),
								esc_html__( 'Google Fonts website', 'doctype' )
							)
						),
					),
				),
			),
		),

		'doctype_portfolio' => array(
			'title'   => esc_html__( 'Portfolio Settings', 'doctype' ),
			'panel'   => 'doctype_options_panel',
			'options' => array(
				'doctype_portfolio_title'                 => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Portfolio Title', 'doctype' ),
						'description' => esc_html__( 'Enter the default title for the portfolio page template header section.', 'doctype' ),
					),
				),
				'doctype_portfolio_subtitle'              => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Portfolio Subtitle', 'doctype' ),
						'description' => esc_html__( 'Enter the default subtitle for the portfolio page template header section.', 'doctype' ),
					),
				),
				'doctype_portfolio_related_project_text'  => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Related Project Text', 'doctype' ),
						'description' => esc_html__( 'Enter the text for related projects.', 'doctype' ),
					),
				),
				'doctype_portfolio_show_related_projects' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => esc_html__( 'Show Related Projects', 'doctype' ),
						'type'  => 'checkbox',
					),
				),
				'doctype_portfolio_show_portfolio_cta'    => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => esc_html__( 'Show Portfolio CTA', 'doctype' ),
						'type'  => 'checkbox',
					),
				),
				'doctype_portfolio_cta_text'  => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'CTA Text', 'doctype' ),
						'description' => esc_html__( 'Enter the text for call to action on portfolio page.', 'doctype' ),
					),
				),
				'doctype_portfolio_cta_button_text'  => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'CTA Button Text', 'doctype' ),
						'description' => esc_html__( 'Enter the text for call to action button on portfolio page.', 'doctype' ),
					),
				),

				'doctype_portfolio_cta_button_link'  => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'CTA Button Link', 'doctype' ),
						'description' => esc_html__( 'Enter the url for call to action button link on portfolio page.', 'doctype' ),
					),
				),
			),
		),

	);

	/**
	 * Filter the control definitions for the Customizer.
	 *
	 * '[section_id]' => array(
	 *     'title' => esc_html__( '[Section Title]', 'doctype' ),
	 *     'description' => esc_html__( '[Section description]', 'doctype' ),
	 *     'options' => array(
	 *         '[setting-id]' => array(
	 *             'setting' => array(
	 *                 [setting-parameter] => [value]
	 *             ),
	 *            'control' => array(
	 *                 [control-parameter] => [value]
	 *             ),
	 *         ),
	 *    ),
	 * ),
	 *
	 * @since 1.0.0.
	 *
	 * @param array    $definitions    The array containing all of the Customizer definitions.
	 */
	$definitions = apply_filters( 'doctype_customizer_definitions', $definitions );

	return $definitions;
}
