<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 * Learn more: https://codex.wordpress.org/Template_Hierarchy
 *
 * @package StagFramework
 */

get_header();

$blog_title    = doctype_get_thememod_value( 'doctype_blog_title' );
$blog_subtitle = doctype_get_thememod_value( 'doctype_blog_subtitle' );

?>

	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">

		<header class="page-header">
			<?php if( ! empty( $blog_title ) ) echo "<h1 class='blog-title'>{$blog_title}</h1>"; ?>
			<?php if( ! empty( $blog_subtitle ) ) echo "<p class='blog-subtitle'>{$blog_subtitle}</p>"; ?>
		</header>

		<?php if( have_posts() ): ?>

			<?php /* Start the Loop */ ?>
			<?php while ( have_posts() ) : the_post(); ?>

				<?php
					/* Include the Post-Format-specific template for the content.
					 * If you want to overload this in a child theme then include a file
					 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
					 */
					get_template_part( 'content', get_post_format() );
				?>

			<?php endwhile; ?>

			<?php stag_content_nav( 'nav-below' ); ?>

		<?php else : ?>

			<?php get_template_part( 'no-results', 'index' ); ?>

		<?php endif; ?>

		</main><!-- #main -->
	</div><!-- #primary -->

<?php get_footer(); ?>
